@@ -39,6 +39,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <totem-pl-parser.h>
+#include <totem-scrsaver.h>
 
 #include <dbus/dbus-glib.h>
 
@@ -109,6 +110,7 @@ typedef struct _TotemEmbedded {
 	GtkWidget *pp_button;
 	GtkWidget *pp_fs_button;
 	TotemStatusbar *statusbar;
+	TotemScrsaver *scrsaver;
 	int width, height;
 	const char *mimetype;
 	char *base_uri;
@@ -337,6 +339,7 @@ totem_embedded_set_state (TotemEmbedded *emb, TotemStates state)
 		break;
 	}
 
+	totem_scrsaver_set_state (emb->scrsaver, (state == STATE_PLAYING) ? FALSE : TRUE);
 	gtk_image_set_from_stock (GTK_IMAGE (image), id, GTK_ICON_SIZE_MENU);
 	gtk_tool_button_set_stock_id (GTK_TOOL_BUTTON (emb->pp_fs_button), id);
 
@@ -495,6 +498,8 @@ totem_embedded_play (TotemEmbedded *emb,
 {
 	GError *err = NULL;
 
+	totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), FALSE);
+
 	if (bacon_video_widget_play (emb->bvw, &err) != FALSE) {
 		totem_embedded_set_state (emb, STATE_PLAYING);
 		totem_embedded_set_pp_state (emb, TRUE);
@@ -1248,9 +1253,8 @@ on_play_pause (GtkWidget *widget, TotemEmbedded *emb)
 	if (emb->state == STATE_PLAYING) {
 		totem_embedded_pause (emb, NULL);
 	} else {
-		totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), FALSE);
-
 		if (emb->current_uri == NULL) {
+			totem_glow_button_set_glow (TOTEM_GLOW_BUTTON (emb->pp_button), FALSE);
 			g_signal_emit (emb, signals[BUTTON_PRESS], 0,
 				       GDK_CURRENT_TIME, 0);
 		} else {
@@ -1672,6 +1676,7 @@ totem_embedded_construct (TotemEmbedded *emb,
 	emb->fs_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_widget_realize (emb->fs_window);
 	gtk_window_set_title (GTK_WINDOW (emb->fs_window), _("Totem Movie Player"));
+	gtk_window_set_default_icon_name ("totem");
 
 	emb->fs = totem_fullscreen_new (GTK_WINDOW (emb->fs_window));
 	totem_fullscreen_set_video_widget (emb->fs, emb->bvw);
@@ -1760,8 +1765,10 @@ totem_embedded_construct (TotemEmbedded *emb,
 	emb->statusbar = TOTEM_STATUSBAR (gtk_builder_get_object (emb->xml, "statusbar"));
 	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (emb->statusbar), FALSE);
 
-	if (!emb->hidden)
+	if (!emb->hidden) {
 		gtk_widget_set_size_request (emb->window, width, height);
+		emb->scrsaver = totem_scrsaver_new ();
+	}
 
 #ifdef GNOME_ENABLE_DEBUG
 	child = GTK_WIDGET (gtk_builder_get_object (emb->xml, "controls"));
@@ -1932,15 +1939,31 @@ totem_embedded_clear_playlist (TotemEmbedded *embedded)
 static int
 totem_embedded_parse_duration (const char *duration)
 {
-	int hours, minutes, seconds, tenths;
+	int hours, minutes, seconds, fractions;
 
 	if (!duration)
 		return -1;
 
+	/* Formats used by both ASX and RAM files */
+	if (sscanf (duration, "%d:%d:%d.%d", &hours, &minutes, &seconds, &fractions) == 4) {
+		int ret = hours * 3600 + minutes * 60 + seconds;
+		if (ret == 0 && fractions > 0)
+			ret = 1;
+		return ret;
+	}
 	if (sscanf (duration, "%d:%d:%d", &hours, &minutes, &seconds) == 3)
 		return hours * 3600 + minutes * 60 + seconds;
-	if (sscanf (duration, "%d:%d.%d", &minutes, &seconds, &tenths) == 3)
+	if (sscanf (duration, "%d:%d.%d", &minutes, &seconds, &fractions) == 3) {
+		int ret = minutes * 60 + seconds;
+		if (ret == 0 && fractions > 0)
+			ret = 1;
+		return ret;
+	}
+	if (sscanf (duration, "%d:%d", &minutes, &seconds) == 2)
 		return minutes * 60 + seconds;
+	/* PLS files format */
+	if (sscanf (duration, "%d", &seconds) == 1)
+		return seconds;
 
 	return -1;
 }
