@@ -19,7 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: totemGMPPlugin.cpp 4052 2007-02-19 16:01:17Z chpe $
+ * $Id: totemGMPPlugin.cpp 4534 2007-08-16 20:06:42Z hadess $
  */
 
 #include <mozilla-config.h>
@@ -48,7 +48,6 @@
 
 #include "totemGMPPlugin.h"
 
-/* FIXME */
 #define TOTEM_GMP_VERSION_BUILD "11.0.0.1024"
 
 /* 89cf81a7-1156-456f-b060-c2187df9a27c */
@@ -60,21 +59,16 @@ static const char kClassDescription[] = "totemGMPPlugin";
 static const char kPluginDescription[] = "Windows Media Player Plug-in 10 (compatible; Totem)";
 
 static const totemPluginMimeEntry kMimeTypes[] = {
-	{ "application/x-mplayer2", "avi, wma, wmv", "video/x-msvideo", FALSE },
-	{ "video/x-ms-asf-plugin", "asf, wmv", "video/x-ms-asf", FALSE },
-	{ "video/x-msvideo", "asf, wmv", NULL, FALSE },
-	{ "video/x-ms-asf", "asf", NULL, FALSE },
-	{ "video/x-ms-wmv", "wmv", "video/x-ms-wmv", FALSE },
-	{ "video/x-wmv", "wmv", "video/x-ms-wmv", FALSE },
-	{ "video/x-ms-wvx", "wmv", "video/x-ms-wmv", FALSE },
-	{ "video/x-ms-wm", "wmv", "video/x-ms-wmv", FALSE },
-	{ "video/x-ms-asx", "asx", NULL, TRUE },
-	{ "audio/x-ms-asx", "asx", NULL, TRUE },
-	{ "video/x-ms-wma", "wma", NULL, TRUE },
-	{ "audio/x-ms-wax", "wax", NULL, TRUE },
-	{ "video/mpeg", "mpg", NULL, TRUE },
-	{ "audio/mpeg", "mp3", NULL, TRUE },
-	{ "audio/x-mpegurl", "m3u", NULL, TRUE }
+	{ "application/x-mplayer2", "avi, wma, wmv", "video/x-msvideo" },
+	{ "video/x-ms-asf-plugin", "asf, wmv", "video/x-ms-asf" },
+	{ "video/x-msvideo", "asf, wmv", NULL },
+	{ "video/x-ms-asf", "asf", NULL },
+	{ "video/x-ms-wmv", "wmv", "video/x-ms-wmv" },
+	{ "video/x-wmv", "wmv", "video/x-ms-wmv" },
+	{ "video/x-ms-wvx", "wmv", "video/x-ms-wmv" },
+	{ "video/x-ms-wm", "wmv", "video/x-ms-wmv" },
+	{ "application/x-ms-wms", "wms", "video/x-ms-wmv" },
+	{ "application/asx", "asx", "audio/x-ms-asx" }
 };
 
 void*
