@@ -19,7 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: totemNarrowSpacePlugin.cpp 3928 2007-01-22 14:59:07Z chpe $
+ * $Id: totemNarrowSpacePlugin.cpp 4524 2007-08-15 14:47:50Z hadess $
  */
 
 #include <mozilla-config.h>
@@ -36,44 +36,26 @@
 /* define GNOME_ENABLE_DEBUG for more debug spew */
 #include "debug.h"
 
+#include "totemDebug.h"
 #include "totemClassInfo.h"
+
 #include "totemNarrowSpacePlugin.h"
 
-
-#define WARN_UNIMPLEMENTED()\
-static PRBool warned = PR_FALSE;\
-if (!warned) {\
-	D ("NarrowSpace scriptable: use of unimplemented function '%s'", __FUNCTION__);\
-	warned = PR_TRUE;\
-}
-
-#define SHOW_CALLS
-
-#ifdef SHOW_CALLS
-#define SHOW_CALL()\
-static PRBool called = PR_FALSE;\
-if (!called) {\
-	D ("NOTE! Use of function 'totemINarrowSpace::%s'", __FUNCTION__);\
-	called = PR_TRUE;\
-}
-#else
-#define SHOW_CALL()
-#endif
-
 /* 2e390ee1-f0e3-423c-9764-f5ab50a40c06 */
 static const nsCID kClassID = 
 { 0x2e390ee1, 0xf0e3, 0x423c, \
   { 0x97, 0x64, 0xf5, 0xab, 0x50, 0xa4, 0x0c, 0x06 } };
 
 static const char kClassDescription[] = "totemNarrowSpacePlugin";
-static const char kPluginDescription[] = "QuickTime Plug-in 7.1.3";
+#define QUICKTIME_VERSION "7.2.0"
+static const char kPluginDescription[] = "QuickTime Plug-in "QUICKTIME_VERSION;
 
 static const totemPluginMimeEntry kMimeTypes[] = {
-	{ "video/quicktime", "mov", NULL, FALSE },
-	{ "video/mp4", "mp4", NULL, FALSE },
-	{ "image/x-macpaint", "pntg", NULL, FALSE },
-	{ "image/x-quicktime", "pict, pict1, pict2", "image/x-pict", FALSE },
-	{ "application/x-quicktime-media-link", "qtl", NULL, TRUE }
+	{ "video/quicktime", "mov", NULL },
+	{ "video/mp4", "mp4", NULL },
+	{ "image/x-macpaint", "pntg", NULL },
+	{ "image/x-quicktime", "pict, pict1, pict2", "image/x-pict" },
+	{ "video/x-m4v", "m4v", NULL },
 };
 
 void*
@@ -88,10 +70,10 @@ totemScriptablePlugin::operator new (size_t aSize) CPP_THROW_NEW
 }
 
 totemScriptablePlugin::totemScriptablePlugin (totemPlugin *aPlugin)
-  : mPlugin(aPlugin),
+  : mPluginState(eState_Waiting),
+    mPlugin(aPlugin),
     mRate(1.0),
-    mVolume(100),
-    mPluginState(eState_Waiting)
+    mVolume(100)
 {
   D ("%s ctor [%p]", kClassDescription, (void*) this);
 }
@@ -132,11 +114,13 @@ TOTEM_CLASSINFO_END
 
 /* totemINarrowSpacePlayer */
 
+#define TOTEM_SCRIPTABLE_INTERFACE "totemINarrowSpacePlayer"
+
 /* boolean GetAutoPlay (); */
 NS_IMETHODIMP
 totemScriptablePlugin::GetAutoPlay(PRBool *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = mAutoPlay;
   return NS_OK;
@@ -146,7 +130,7 @@ totemScriptablePlugin::GetAutoPlay(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetAutoPlay(PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mAutoPlay = enabled != PR_FALSE;
   return NS_OK;
@@ -156,7 +140,7 @@ totemScriptablePlugin::SetAutoPlay(PRBool enabled)
 NS_IMETHODIMP
 totemScriptablePlugin::GetBgColor(nsACString & _retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   _retval.Assign (mBackgroundColour);
   return NS_OK;
@@ -166,7 +150,7 @@ totemScriptablePlugin::GetBgColor(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetBgColor(const nsACString & colour)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mBackgroundColour = colour;
   return NS_OK;
@@ -179,7 +163,7 @@ totemScriptablePlugin::GetComponentVersion (const nsACString & type,
 					    const nsACString & vendor,
 					    nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED ();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED ();
   D ("GetComponentVersion [%s, %s, %s]",
      nsCString(type).get(),
      nsCString(subtype).get(),
@@ -193,7 +177,7 @@ totemScriptablePlugin::GetComponentVersion (const nsACString & type,
 NS_IMETHODIMP
 totemScriptablePlugin::GetControllerVisible(PRBool *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
   *_retval = mControllerVisible;
   return NS_OK;
 }
@@ -202,7 +186,7 @@ totemScriptablePlugin::GetControllerVisible(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetControllerVisible(PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mControllerVisible = enabled != PR_FALSE;
   return NS_OK;
@@ -212,7 +196,7 @@ totemScriptablePlugin::SetControllerVisible(PRBool enabled)
 NS_IMETHODIMP
 totemScriptablePlugin::GetDuration(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = 0;
   return NS_OK;
@@ -222,7 +206,7 @@ totemScriptablePlugin::GetDuration(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetEndTime(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = 0;
   return NS_OK;
@@ -232,7 +216,7 @@ totemScriptablePlugin::GetEndTime(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetEndTime(PRUint32 time)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -241,7 +225,7 @@ totemScriptablePlugin::SetEndTime(PRUint32 time)
 NS_IMETHODIMP
 totemScriptablePlugin::GetFieldOfView (float *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
   return NS_ERROR_NOT_AVAILABLE;
 }
 
@@ -249,7 +233,7 @@ totemScriptablePlugin::GetFieldOfView (float *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetFieldOfView(float angle)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
   return NS_ERROR_NOT_AVAILABLE;
 }
 
@@ -257,7 +241,7 @@ totemScriptablePlugin::SetFieldOfView(float angle)
 NS_IMETHODIMP
 totemScriptablePlugin::GoPreviousNode()
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
   return NS_ERROR_NOT_AVAILABLE;
 }
 
@@ -265,7 +249,7 @@ totemScriptablePlugin::GoPreviousNode()
 NS_IMETHODIMP
 totemScriptablePlugin::GetHotspotTarget(PRUint32 id, nsACString & _retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
   return NS_ERROR_NOT_AVAILABLE;
 }
 
@@ -273,7 +257,7 @@ totemScriptablePlugin::GetHotspotTarget(PRUint32 id, nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetHotspotTarget(PRUint32 id, const nsACString & target)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
   return NS_ERROR_NOT_AVAILABLE;
 }
 
@@ -281,7 +265,7 @@ totemScriptablePlugin::SetHotspotTarget(PRUint32 id, const nsACString & target)
 NS_IMETHODIMP
 totemScriptablePlugin::GetHotspotUrl(PRUint32 id, nsACString & _retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
   return NS_ERROR_NOT_AVAILABLE;
 }
 
@@ -289,7 +273,7 @@ totemScriptablePlugin::GetHotspotUrl(PRUint32 id, nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetHotspotUrl(PRUint32 id, const nsACString & url)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
   return NS_ERROR_NOT_AVAILABLE;
 }
 
@@ -297,7 +281,7 @@ totemScriptablePlugin::SetHotspotUrl(PRUint32 id, const nsACString & url)
 NS_IMETHODIMP
 totemScriptablePlugin::GetHREF(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -306,7 +290,7 @@ totemScriptablePlugin::GetHREF(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetHREF(const nsACString & href)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -315,7 +299,7 @@ totemScriptablePlugin::SetHREF(const nsACString & href)
 NS_IMETHODIMP
 totemScriptablePlugin::GetIsLooping(PRBool *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   *_retval = mIsLooping;
   return NS_OK;
@@ -325,7 +309,7 @@ totemScriptablePlugin::GetIsLooping(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetIsLooping(PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mIsLooping = enabled != PR_FALSE;
   return NS_OK;
@@ -335,7 +319,7 @@ totemScriptablePlugin::SetIsLooping(PRBool enabled)
 NS_IMETHODIMP
 totemScriptablePlugin::GetIsQuickTimeRegistered(PRBool *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = PR_FALSE;
   return NS_OK;
@@ -345,7 +329,7 @@ totemScriptablePlugin::GetIsQuickTimeRegistered(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetIsVRMovie(PRBool *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   *_retval = PR_FALSE;
   return NS_OK;
@@ -355,7 +339,7 @@ totemScriptablePlugin::GetIsVRMovie(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetKioskMode(PRBool *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   *_retval = mKioskMode;
   return NS_OK;
@@ -365,7 +349,7 @@ totemScriptablePlugin::GetKioskMode(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetKioskMode(PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mKioskMode = enabled != PR_FALSE;
   return NS_OK;
@@ -375,7 +359,7 @@ totemScriptablePlugin::SetKioskMode(PRBool enabled)
 NS_IMETHODIMP
 totemScriptablePlugin::GetLanguage(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   _retval.Assign ("English");
   return NS_OK;
@@ -385,7 +369,7 @@ totemScriptablePlugin::GetLanguage(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetLanguage(const nsACString & language)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -394,7 +378,7 @@ totemScriptablePlugin::SetLanguage(const nsACString & language)
 NS_IMETHODIMP
 totemScriptablePlugin::GetLoopIsPalindrome(PRBool *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   *_retval = mLoopIsPalindrome;
   return NS_OK;
@@ -404,7 +388,7 @@ totemScriptablePlugin::GetLoopIsPalindrome(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetLoopIsPalindrome(PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mLoopIsPalindrome = enabled != PR_FALSE;
   return NS_OK;
@@ -414,7 +398,7 @@ totemScriptablePlugin::SetLoopIsPalindrome(PRBool enabled)
 NS_IMETHODIMP
 totemScriptablePlugin::GetMatrix(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   _retval.Assign (mMatrix);
   return NS_OK;
@@ -424,7 +408,7 @@ totemScriptablePlugin::GetMatrix(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetMatrix(const nsACString & matrix)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mMatrix = matrix;
   return NS_OK;
@@ -434,7 +418,7 @@ totemScriptablePlugin::SetMatrix(const nsACString & matrix)
 NS_IMETHODIMP
 totemScriptablePlugin::GetMaxBytesLoaded(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -443,7 +427,7 @@ totemScriptablePlugin::GetMaxBytesLoaded(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetMaxTimeLoaded(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -452,7 +436,7 @@ totemScriptablePlugin::GetMaxTimeLoaded(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetMIMEType(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   _retval.Assign ("video/quicktime");
   return NS_OK;
@@ -462,7 +446,7 @@ totemScriptablePlugin::GetMIMEType(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetMovieID(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -471,7 +455,7 @@ totemScriptablePlugin::GetMovieID(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetMovieID(PRUint32 id)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -480,7 +464,7 @@ totemScriptablePlugin::SetMovieID(PRUint32 id)
 NS_IMETHODIMP
 totemScriptablePlugin::GetMovieName(nsACString & _retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   _retval.Assign (mMovieName);
   return NS_OK;
@@ -490,7 +474,7 @@ totemScriptablePlugin::GetMovieName(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetMovieName(const nsACString & name)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mMovieName = name;
   return NS_OK;
@@ -500,7 +484,7 @@ totemScriptablePlugin::SetMovieName(const nsACString & name)
 NS_IMETHODIMP
 totemScriptablePlugin::GetMovieSize(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = 0;
   return NS_OK;
@@ -510,7 +494,7 @@ totemScriptablePlugin::GetMovieSize(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetMute(PRBool *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   *_retval = mMute;
   return NS_OK;
@@ -520,7 +504,7 @@ totemScriptablePlugin::GetMute(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetMute(PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mMute = enabled != PR_FALSE;
   return NS_OK;
@@ -530,7 +514,7 @@ totemScriptablePlugin::SetMute(PRBool enabled)
 NS_IMETHODIMP
 totemScriptablePlugin::GetNodeCount(PRUint32 *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   return NS_ERROR_NOT_AVAILABLE;
 }
@@ -539,7 +523,7 @@ totemScriptablePlugin::GetNodeCount(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetNodeID(PRUint32 *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   return NS_ERROR_NOT_AVAILABLE;
 }
@@ -548,7 +532,7 @@ totemScriptablePlugin::GetNodeID(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetNodeID(PRUint32 id)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   return NS_ERROR_NOT_AVAILABLE;
 }
@@ -557,7 +541,7 @@ totemScriptablePlugin::SetNodeID(PRUint32 id)
 NS_IMETHODIMP
 totemScriptablePlugin::GetPanAngle(float *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   return NS_ERROR_NOT_AVAILABLE;
 }
@@ -566,7 +550,7 @@ totemScriptablePlugin::GetPanAngle(float *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetPanAngle(float angle)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   return NS_ERROR_NOT_AVAILABLE;
 }
@@ -575,7 +559,7 @@ totemScriptablePlugin::SetPanAngle(float angle)
 NS_IMETHODIMP
 totemScriptablePlugin::Play ()
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   NS_ENSURE_STATE (IsValid ());
 
@@ -586,7 +570,7 @@ totemScriptablePlugin::Play ()
 NS_IMETHODIMP
 totemScriptablePlugin::GetPlayEveryFrame(PRBool *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   *_retval = mPlayEveryFrame;
   return NS_OK;
@@ -596,7 +580,7 @@ totemScriptablePlugin::GetPlayEveryFrame(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetPlayEveryFrame(PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mPlayEveryFrame = enabled != PR_FALSE;
   return NS_OK;
@@ -606,8 +590,6 @@ totemScriptablePlugin::SetPlayEveryFrame(PRBool enabled)
 NS_IMETHODIMP
 totemScriptablePlugin::GetPluginStatus(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
-
   static const char *kState[] = {
     "Complete",
     "Error:<%d>",
@@ -629,9 +611,7 @@ totemScriptablePlugin::GetPluginStatus(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetPluginVersion(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
-
-  _retval.Assign ("7.0"); /* FIXME */
+  _retval.Assign (QUICKTIME_VERSION);
   return NS_OK;
 }
 
@@ -640,7 +620,7 @@ NS_IMETHODIMP
 totemScriptablePlugin::GetQTNEXTUrl (PRUint32 index,
 				     nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -650,7 +630,7 @@ NS_IMETHODIMP
 totemScriptablePlugin::SetQTNEXTUrl (PRUint32 index,
 				     const nsACString & url)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -659,7 +639,7 @@ totemScriptablePlugin::SetQTNEXTUrl (PRUint32 index,
 NS_IMETHODIMP
 totemScriptablePlugin::GetQuickTimeConnectionSpeed(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = 300000; /* FIXME */
   return NS_OK;
@@ -669,7 +649,7 @@ totemScriptablePlugin::GetQuickTimeConnectionSpeed(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetQuickTimeLanguage(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   _retval.Assign ("English"); /* FIXME */
   return NS_OK;
@@ -679,9 +659,7 @@ totemScriptablePlugin::GetQuickTimeLanguage(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetQuickTimeVersion(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
-
-  _retval.Assign ("7.0"); /* FIXME */
+  _retval.Assign (QUICKTIME_VERSION);
   return NS_OK;
 }
 
@@ -689,7 +667,7 @@ totemScriptablePlugin::GetQuickTimeVersion(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetRate(float *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = mRate;
   return NS_OK;
@@ -699,7 +677,7 @@ totemScriptablePlugin::GetRate(float *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetRate(float rate)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mRate = rate;
   return NS_OK;
@@ -709,7 +687,7 @@ totemScriptablePlugin::SetRate(float rate)
 NS_IMETHODIMP
 totemScriptablePlugin::SetRectangle(const nsACString & rectangle)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mRectangle = rectangle;
   return NS_OK;
@@ -719,7 +697,7 @@ totemScriptablePlugin::SetRectangle(const nsACString & rectangle)
 NS_IMETHODIMP
 totemScriptablePlugin::GetRectangle(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   _retval.Assign (mRectangle);
   return NS_OK;
@@ -729,7 +707,7 @@ totemScriptablePlugin::GetRectangle(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetResetPropertiesOnReload(PRBool *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   *_retval = mResetPropertiesOnReload;
   return NS_OK;
@@ -739,7 +717,7 @@ totemScriptablePlugin::GetResetPropertiesOnReload(PRBool *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetResetPropertiesOnReload(PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mResetPropertiesOnReload = enabled != PR_FALSE;
   return NS_OK;
@@ -749,7 +727,7 @@ totemScriptablePlugin::SetResetPropertiesOnReload(PRBool enabled)
 NS_IMETHODIMP
 totemScriptablePlugin::Rewind ()
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   NS_ENSURE_STATE (IsValid ());
 
@@ -760,7 +738,7 @@ totemScriptablePlugin::Rewind ()
 NS_IMETHODIMP
 totemScriptablePlugin::ShowDefaultView()
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   return NS_OK;
 }
@@ -771,7 +749,7 @@ totemScriptablePlugin::GetSpriteTrackVariable (PRUint32 track,
 					       PRUint32 index,
 					       nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -782,7 +760,7 @@ totemScriptablePlugin::SetSpriteTrackVariable (PRUint32 track,
 					       PRUint32 index,
 					       const nsACString & value)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -791,7 +769,7 @@ totemScriptablePlugin::SetSpriteTrackVariable (PRUint32 track,
 NS_IMETHODIMP
 totemScriptablePlugin::SetStartTime(PRUint32 time)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -800,7 +778,7 @@ totemScriptablePlugin::SetStartTime(PRUint32 time)
 NS_IMETHODIMP
 totemScriptablePlugin::GetStartTime (PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = 0; /* FIXME */
   return NS_OK;
@@ -810,7 +788,7 @@ totemScriptablePlugin::GetStartTime (PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::Step(PRInt32 steps)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -819,7 +797,7 @@ totemScriptablePlugin::Step(PRInt32 steps)
 NS_IMETHODIMP
 totemScriptablePlugin::Stop ()
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   NS_ENSURE_STATE (IsValid ());
 
@@ -830,7 +808,7 @@ totemScriptablePlugin::Stop ()
 NS_IMETHODIMP
 totemScriptablePlugin::GetTarget(nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -839,7 +817,7 @@ totemScriptablePlugin::GetTarget(nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetTarget(const nsACString & target)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -848,7 +826,7 @@ totemScriptablePlugin::SetTarget(const nsACString & target)
 NS_IMETHODIMP
 totemScriptablePlugin::GetTiltAngle(float *_retval)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   return NS_ERROR_NOT_AVAILABLE;
 }
@@ -857,7 +835,7 @@ totemScriptablePlugin::GetTiltAngle(float *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetTiltAngle(float angle)
 {
-  SHOW_CALL ();
+  TOTEM_SCRIPTABLE_LOG_ACCESS ();
 
   return NS_ERROR_NOT_AVAILABLE;
 }
@@ -866,7 +844,7 @@ totemScriptablePlugin::SetTiltAngle(float angle)
 NS_IMETHODIMP
 totemScriptablePlugin::GetTime(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = 0;
   return NS_OK;
@@ -876,7 +854,7 @@ totemScriptablePlugin::GetTime(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetTime(PRUint32 time)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -885,7 +863,7 @@ totemScriptablePlugin::SetTime(PRUint32 time)
 NS_IMETHODIMP
 totemScriptablePlugin::GetTimeScale(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = 0;
   return NS_OK;
@@ -895,7 +873,7 @@ totemScriptablePlugin::GetTimeScale(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::GetTrackCount(PRUint32 *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = 1;
   return NS_OK;
@@ -906,7 +884,7 @@ NS_IMETHODIMP
 totemScriptablePlugin::GetTrackEnabled (PRUint32 index,
 					PRBool *_retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   *_retval = PR_TRUE;
   return NS_OK;
@@ -917,7 +895,7 @@ NS_IMETHODIMP
 totemScriptablePlugin::SetTrackEnabled (PRUint32 index,
 					PRBool enabled)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -927,7 +905,7 @@ NS_IMETHODIMP
 totemScriptablePlugin::GetTrackName (PRUint32 index,
 				     nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -937,7 +915,7 @@ NS_IMETHODIMP
 totemScriptablePlugin::GetTrackType (PRUint32 index,
 				     nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -946,7 +924,7 @@ totemScriptablePlugin::GetTrackType (PRUint32 index,
 NS_IMETHODIMP
 totemScriptablePlugin::GetURL (nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -955,7 +933,7 @@ totemScriptablePlugin::GetURL (nsACString & _retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetURL (const nsACString & url)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -965,7 +943,7 @@ NS_IMETHODIMP
 totemScriptablePlugin::GetUserData  (const nsACString & identifier,
 				     nsACString & _retval)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   return NS_OK;
 }
@@ -982,7 +960,7 @@ totemScriptablePlugin::GetVolume(PRUint32 *_retval)
 NS_IMETHODIMP
 totemScriptablePlugin::SetVolume(PRUint32 volume)
 {
-  WARN_UNIMPLEMENTED();
+  TOTEM_SCRIPTABLE_WARN_UNIMPLEMENTED();
 
   mVolume = volume;
   return NS_OK;
