@@ -756,6 +756,10 @@ totemPlugin::RequestStream (PRBool aForceViewer)
 	if (spec.IsEmpty ())
 		return;
 
+	/* If we don't have a proxy yet */
+	if (!mViewerReady)
+		return;
+
 	/* If the URL is supported and the caller isn't asking us to make
 	 * the viewer open the stream, we call OpenStream, and
 	 * otherwise OpenURI. */
@@ -785,6 +789,12 @@ totemPlugin::RequestStream (PRBool aForceViewer)
 	}
 
 	/* FIXME: start playing in the callbacks ! */
+
+#ifdef TOTEM_NARROWSPACE_PLUGIN
+	if (mScriptable) {
+		mScriptable->mPluginState = totemScriptablePlugin::eState_Playable;
+	}
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
 }
 
 void
@@ -805,6 +815,12 @@ totemPlugin::UnsetStream ()
 	/* Calling DestroyStream should already have set this to NULL */
 	NS_ASSERTION (!mStream, "Should not have a stream anymore");
 	mStream = nsnull; /* just to make sure */
+
+#ifdef TOTEM_NARROWSPACE_PLUGIN
+	if (mScriptable) {
+		mScriptable->mPluginState = totemScriptablePlugin::eState_Waiting;
+	}
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
 }
 
 /* Callbacks */
@@ -928,7 +944,14 @@ totemPlugin::ViewerOpenStreamCallback (DBusGProxy *aProxy,
 		plugin->mExpectingStream = PR_FALSE;
 
 		D ("GetURLNotify '%s' failed with error %d", spec.get (), err);
+		return;
 	}
+
+#ifdef TOTEM_NARROWSPACE_PLUGIN
+	if (plugin->mScriptable) {
+		plugin->mScriptable->mPluginState = totemScriptablePlugin::eState_Playable;
+	}
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
 }
 
 /* static */ void PR_CALLBACK
@@ -951,6 +974,12 @@ totemPlugin::ViewerOpenURICallback (DBusGProxy *aProxy,
 		return;
 	}
 
+#ifdef TOTEM_NARROWSPACE_PLUGIN
+	if (plugin->mScriptable) {
+		plugin->mScriptable->mPluginState = totemScriptablePlugin::eState_Playable;
+	}
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
+
 	/* FIXME this isn't the best way... */
 	if (plugin->mAutostart) {
 		plugin->DoCommand (TOTEM_COMMAND_PLAY);
@@ -1614,17 +1643,6 @@ totemPlugin::Init (NPMIMEType mimetype,
 	mHidden = g_hash_table_lookup (args, "hidden") != NULL &&
 		  GetBooleanValue (args, "hidden", PR_TRUE);
 
-#ifdef TOTEM_GMP_PLUGIN
-	if (height == 40) {
-		mAudioOnly = PR_TRUE;
-	}
-#endif /* TOTEM_GMP_PLUGIN */
-#if defined(TOTEM_NARROWSPACE_PLUGIN) || defined (TOTEM_BASIC_PLUGIN)
-	if (height <= 16) {
-		mAudioOnly = PR_TRUE;
-	}
-#endif /* TOTEM_NARROWSPACE_PLUGIN */
-
 	/* Most for RealAudio streams, but also used as a replacement for
 	 * HIDDEN=TRUE attribute.
 	 */
@@ -1783,6 +1801,19 @@ totemPlugin::Init (NPMIMEType mimetype,
 	//FIXME handle starttime and endtime
 	// http://www.htmlcodetutorial.com/embeddedobjects/_EMBED_STARTTIME.html
 
+	/* Minimum heights of the different plugins, note that the
+	 * controllers need to be showing, otherwise it's useless */
+#ifdef TOTEM_GMP_PLUGIN
+	if (height == 40 && !mControllerHidden) {
+		mAudioOnly = PR_TRUE;
+	}
+#endif /* TOTEM_GMP_PLUGIN */
+#if defined(TOTEM_NARROWSPACE_PLUGIN) || defined (TOTEM_BASIC_PLUGIN)
+	if (height <= 16 && !mControllerHidden) {
+		mAudioOnly = PR_TRUE;
+	}
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
+
 #ifdef TOTEM_NARROWSPACE_PLUGIN
 	/* We need to autostart if we're using an HREF
 	 * otherwise the start image isn't shown */
@@ -1916,6 +1947,12 @@ totemPlugin::NewStream (NPMIMEType type,
 		mStreamType = NP_ASFILE;
 	}
 
+#ifdef TOTEM_NARROWSPACE_PLUGIN
+	if (mScriptable) {
+		mScriptable->mPluginState = totemScriptablePlugin::eState_Loading;
+	}
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
+
 	mStream = stream;
 
 	mCheckedForPlaylist = PR_FALSE;
@@ -2052,9 +2089,6 @@ totemPlugin::StreamAsFile (NPStream *stream,
 
 	D ("StreamAsFile filename '%s'", fname);
 
-	/* FIXME: this reads the whole file into memory... try to
-	 * find a way to avoid it.
-	 */
 	if (!mCheckedForPlaylist) {
 		mIsPlaylist = totem_pl_parser_can_parse_from_filename
 				(fname, TRUE) != FALSE;
@@ -2106,14 +2140,30 @@ totemPlugin::StreamAsFile (NPStream *stream,
 					    G_TYPE_STRING, baseSpec.get (),
 					    G_TYPE_INVALID,
 					    G_TYPE_INVALID);
-	} else {
+	}
+	/* If the file has finished streaming from the network
+	 * and is on the disk, then we should be able to play
+	 * it back from the cache, rather than just stopping there */
+	else {
 		D ("mBytesStreamed %u", mBytesStreamed);
+		retval = dbus_g_proxy_call (mViewerProxy,
+					    "SetLocalCache",
+					    &error,
+					    G_TYPE_STRING, fname,
+					    G_TYPE_INVALID,
+					    G_TYPE_INVALID);
 	}
 
 	if (!retval) {
 		g_warning ("Viewer error: %s", error->message);
 		g_error_free (error);
+		return;
 	}
+#ifdef TOTEM_NARROWSPACE_PLUGIN
+	if (mScriptable) {
+		mScriptable->mPluginState = totemScriptablePlugin::eState_Complete;
+	}
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
 }
     
 void
@@ -2158,6 +2208,10 @@ totemPlugin::GetScriptable (void *_retval)
 		if (!mScriptable)
 			return NPERR_OUT_OF_MEMORY_ERROR;
 
+#ifdef TOTEM_NARROWSPACE_PLUGIN
+		mScriptable->mPluginState = totemScriptablePlugin::eState_Waiting;
+#endif /* TOTEM_NARROWSPACE_PLUGIN */
+
 		NS_ADDREF (mScriptable);
 	}
 
