@@ -837,6 +837,8 @@ on_movie_menu_select (GtkMenuItem *movie_menuitem, Totem *totem)
 
 	g_list_foreach (devices, (GFunc) g_object_unref, NULL);
 	g_list_free (devices);
+
+	totem->drives_changed = FALSE;
 }
 
 static void
@@ -1013,13 +1015,13 @@ previous_chapter_action_callback (GtkAction *action, Totem *totem)
 static void
 skip_forward_action_callback (GtkAction *action, Totem *totem)
 {
-	totem_action_seek_relative (totem, SEEK_FORWARD_OFFSET);
+	totem_action_seek_relative (totem, SEEK_FORWARD_OFFSET * 1000);
 }
 
 static void
 skip_backwards_action_callback (GtkAction *action, Totem *totem)
 {
-	totem_action_seek_relative (totem, SEEK_BACKWARD_OFFSET);
+	totem_action_seek_relative (totem, SEEK_BACKWARD_OFFSET * 1000);
 }
 
 static void
